"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const dateformat_1 = __importDefault(require("dateformat"));
const { promises: Fs } = require("fs");
const fs = require("fs");
const os_1 = __importDefault(require("os"));
class PathHelper {
    static getFileForPage(folder, scanCount, currentPageNumber, filePattern, extension) {
        if (filePattern) {
            return path_1.default.join(folder, `${(0, dateformat_1.default)(new Date(), filePattern)}.${extension}`);
        }
        return path_1.default.join(folder, `scan${scanCount}_page${currentPageNumber}.${extension}`);
    }
    static makeUnique(filePath) {
        if (!fs.existsSync(filePath)) {
            return filePath;
        }
        let parsed = path_1.default.parse(filePath);
        let tryName = `${parsed.dir}${path_1.default.sep}${parsed.name}${(0, dateformat_1.default)(new Date(), "yyyymmdd")}${parsed.ext}`;
        if (!fs.existsSync(tryName)) {
            return tryName;
        }
        parsed = path_1.default.parse(tryName);
        let i = "a";
        while (i <= "z") {
            tryName = `${parsed.dir}${path_1.default.sep}${parsed.name}_${i}${parsed.ext}`;
            if (!fs.existsSync(tryName)) {
                return tryName;
            }
            i = String.fromCharCode(i.charCodeAt(0) + 1);
        }
        throw new Error(`Can not create unique file: ${filePath} iterated until: ${tryName}`);
    }
    static getFileForScan(folder, scanCount, filePattern, extension) {
        if (filePattern) {
            return path_1.default.join(folder, `${(0, dateformat_1.default)(new Date(), filePattern)}.${extension}`);
        }
        return path_1.default.join(folder, `scan${scanCount}.${extension}`);
    }
    static async getOutputFolder(folder) {
        if (typeof folder !== "string") {
            return Fs.mkdtemp(path_1.default.join(os_1.default.tmpdir(), "scan-to-pc"));
        }
        return folder;
    }
}
exports.default = PathHelper;
//# sourceMappingURL=PathHelper.js.map